AnalyticsEventType enum

Canonical Segment event types.

Inheritance
Available extensions

Values

track → const AnalyticsEventType
identify → const AnalyticsEventType
page → const AnalyticsEventType
screen → const AnalyticsEventType
group → const AnalyticsEventType
alias → const AnalyticsEventType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wire String

Available on AnalyticsEventType, provided by the AnalyticsEventTypeWire extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AnalyticsEventType>
A constant List of the values in this enum, in order of their declaration.