CallOptions class
Options accepted by every top-level call.
Constructors
-
CallOptions({String? timestamp, Map<
String, Object?> ? context}) -
const
Properties
- context → AnalyticsProperties?
-
Per-call context overrides (shallow-merged into context.extra).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → String?
-
Per-call timestamp override (ISO-8601).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited