ConsentConfig class
Consent gate configuration.
Constructors
-
ConsentConfig({List<
String> ? granted, bool? strict}) -
const
Properties
-
granted
→ List<
String> ? -
Categories granted at boot.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strict → bool?
-
If true, an event is dropped entirely when NO sink can receive it.
If false (default), events are still buffered until consent is granted.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited